Class: Google::Apis::MybusinessbusinessinformationV1::GoogleUpdatedLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb

Overview

Represents the view of a location as it appears to consumers, which includes updates that are currently serving on Google Maps and Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleUpdatedLocation

Returns a new instance of GoogleUpdatedLocation.



570
571
572
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#diff_maskString

The fields where the values in the view as it appears to consumers are different than the merchant's information. To accept these changes, patch the location. To reject, patch with your preferred values. Corresponds to the JSON property diffMask

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 553

def diff_mask
  @diff_mask
end

#locationGoogle::Apis::MybusinessbusinessinformationV1::Location

A location. See the help center article for a detailed description of these fields, or the category endpoint for a list of valid business categories. Corresponds to the JSON property location



561
562
563
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 561

def location
  @location
end

#pending_maskString

The fields where the merchant has provided an update that is currently in flight and hasn't yet been published to Maps and Search. This mask only tracks the status of the merchant's own edits, not external changes. Corresponds to the JSON property pendingMask

Returns:

  • (String)


568
569
570
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 568

def pending_mask
  @pending_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



575
576
577
578
579
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 575

def update!(**args)
  @diff_mask = args[:diff_mask] if args.key?(:diff_mask)
  @location = args[:location] if args.key?(:location)
  @pending_mask = args[:pending_mask] if args.key?(:pending_mask)
end