Class: Google::Apis::MybusinessbusinessinformationV1::Label
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::Label
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
Label to be used when displaying the price list, section, or item.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#language_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Label
constructor
A new instance of Label.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Label
Returns a new instance of Label.
602 603 604 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the price list, section, or item.
Corresponds to the JSON property description
589 590 591 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 589 def description @description end |
#display_name ⇒ String
Required. Display name for the price list, section, or item.
Corresponds to the JSON property displayName
594 595 596 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 594 def display_name @display_name end |
#language_code ⇒ String
Optional. The BCP-47 language code that these strings apply for. Only one set
of labels may be set per language.
Corresponds to the JSON property languageCode
600 601 602 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 600 def language_code @language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
607 608 609 610 611 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 607 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @language_code = args[:language_code] if args.key?(:language_code) end |