Class: Google::Apis::MybusinessbusinessinformationV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
Response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::MybusinessbusinessinformationV1::Location>
The locations.
-
#next_page_token ⇒ String
If the number of locations exceeded the requested page size, this field is populated with a token to fetch the next page of locations on a subsequent call to
ListLocations. -
#total_size ⇒ Fixnum
The approximate number of Locations in the list irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
720 721 722 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::MybusinessbusinessinformationV1::Location>
The locations.
Corresponds to the JSON property locations
704 705 706 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 704 def locations @locations end |
#next_page_token ⇒ String
If the number of locations exceeded the requested page size, this field is
populated with a token to fetch the next page of locations on a subsequent
call to ListLocations. If there are no more locations, this field is not
present in the response.
Corresponds to the JSON property nextPageToken
712 713 714 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 712 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
The approximate number of Locations in the list irrespective of pagination.
This field will only be returned if filter is used as a query parameter.
Corresponds to the JSON property totalSize
718 719 720 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 718 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
725 726 727 728 729 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 725 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |