Class: Google::Apis::MybusinessbusinessinformationV1::OpenInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb

Overview

Information related to the opening state of the business.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OpenInfo

Returns a new instance of OpenInfo.



1155
1156
1157
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_reopenBoolean Also known as: can_reopen?

Output only. Indicates whether this business is eligible for re-open. Corresponds to the JSON property canReopen

Returns:

  • (Boolean)


1134
1135
1136
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1134

def can_reopen
  @can_reopen
end

#opening_dateGoogle::Apis::MybusinessbusinessinformationV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property openingDate



1147
1148
1149
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1147

def opening_date
  @opening_date
end

#statusString

Required. Indicates whether or not the Location is currently open for business. All locations are open by default, unless updated to be closed. Corresponds to the JSON property status

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1153

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1160
1161
1162
1163
1164
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1160

def update!(**args)
  @can_reopen = args[:can_reopen] if args.key?(:can_reopen)
  @opening_date = args[:opening_date] if args.key?(:opening_date)
  @status = args[:status] if args.key?(:status)
end