Class: Google::Apis::MybusinessbusinessinformationV1::PhoneNumbers

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb

Overview

A collection of phone numbers for the business. During updates, both fields must be set. Clients may not update just the primary or additional phone numbers using the update mask. International phone format is preferred, such as "+1 415 555 0132", see more in (https://developers.google.com/style/phone- numbers#international-phone-numbers).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhoneNumbers

Returns a new instance of PhoneNumbers.



1188
1189
1190
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_phonesArray<String>

Optional. Up to two phone numbers (mobile or landline, no fax) at which your business can be called, in addition to your primary phone number. Corresponds to the JSON property additionalPhones

Returns:

  • (Array<String>)


1179
1180
1181
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1179

def additional_phones
  @additional_phones
end

#primary_phoneString

Required. A phone number that connects to your individual business location as directly as possible. Use a local phone number instead of a central, call center helpline number whenever possible. Corresponds to the JSON property primaryPhone

Returns:

  • (String)


1186
1187
1188
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1186

def primary_phone
  @primary_phone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1193
1194
1195
1196
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1193

def update!(**args)
  @additional_phones = args[:additional_phones] if args.key?(:additional_phones)
  @primary_phone = args[:primary_phone] if args.key?(:primary_phone)
end