Class: Google::Apis::MybusinessbusinessinformationV1::SearchGoogleLocationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb

Overview

Request message for GoogleLocations.SearchGoogleLocations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchGoogleLocationsRequest

Returns a new instance of SearchGoogleLocationsRequest.



1537
1538
1539
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::MybusinessbusinessinformationV1::Location

A location. See the help center article for a detailed description of these fields, or the category endpoint for a list of valid business categories. Corresponds to the JSON property location



1522
1523
1524
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1522

def location
  @location
end

#page_sizeFixnum

The number of matches to return. The default value is 3, with a maximum of 10. Note that latency may increase if more are requested. There is no pagination. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1528
1529
1530
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1528

def page_size
  @page_size
end

#queryString

Text query to search for. The search results from a query string will be less accurate than if providing an exact location, but can provide more inexact matches. Corresponds to the JSON property query

Returns:

  • (String)


1535
1536
1537
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1535

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1542
1543
1544
1545
1546
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1542

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @page_size = args[:page_size] if args.key?(:page_size)
  @query = args[:query] if args.key?(:query)
end