Class: Google::Apis::MybusinessbusinessinformationV1::TimePeriod
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::TimePeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
Represents a span of time that the business is open, starting on the specified open day/time and closing on the specified close day/time. The closing time must occur after the opening time, for example later in the same day, or on a subsequent day.
Instance Attribute Summary collapse
-
#close_day ⇒ String
Required.
-
#close_time ⇒ Google::Apis::MybusinessbusinessinformationV1::TimeOfDay
Represents a time of day.
-
#open_day ⇒ String
Required.
-
#open_time ⇒ Google::Apis::MybusinessbusinessinformationV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimePeriod
constructor
A new instance of TimePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimePeriod
Returns a new instance of TimePeriod.
1871 1872 1873 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#close_day ⇒ String
Required. Indicates the day of the week this period ends on.
Corresponds to the JSON property closeDay
1850 1851 1852 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1850 def close_day @close_day end |
#close_time ⇒ Google::Apis::MybusinessbusinessinformationV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property closeTime
1857 1858 1859 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1857 def close_time @close_time end |
#open_day ⇒ String
Required. Indicates the day of the week this period starts on.
Corresponds to the JSON property openDay
1862 1863 1864 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1862 def open_day @open_day end |
#open_time ⇒ Google::Apis::MybusinessbusinessinformationV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property openTime
1869 1870 1871 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1869 def open_time @open_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1876 1877 1878 1879 1880 1881 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1876 def update!(**args) @close_day = args[:close_day] if args.key?(:close_day) @close_time = args[:close_time] if args.key?(:close_time) @open_day = args[:open_day] if args.key?(:open_day) @open_time = args[:open_time] if args.key?(:open_time) end |