Class: Google::Apis::MybusinessbusinessinformationV1::FreeFormServiceItem
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::FreeFormServiceItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
Represents a free-form service offered by the merchant. These are services that are not exposed as part of our structure service data. The merchant manually enters the names for such services using a geomerchant surface.
Instance Attribute Summary collapse
-
#category ⇒ String
Required.
-
#label ⇒ Google::Apis::MybusinessbusinessinformationV1::Label
Label to be used when displaying the price list, section, or item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FreeFormServiceItem
constructor
A new instance of FreeFormServiceItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FreeFormServiceItem
Returns a new instance of FreeFormServiceItem.
494 495 496 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Required. This field represents the category name (i.e. the category's stable
ID). The category and service_type_id should match the possible
combinations provided in the Category message.
Corresponds to the JSON property category
487 488 489 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 487 def category @category end |
#label ⇒ Google::Apis::MybusinessbusinessinformationV1::Label
Label to be used when displaying the price list, section, or item.
Corresponds to the JSON property label
492 493 494 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 492 def label @label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
499 500 501 502 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 499 def update!(**args) @category = args[:category] if args.key?(:category) @label = args[:label] if args.key?(:label) end |