Class: Google::Apis::MybusinessbusinessinformationV1::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::Metadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
Additional non-user-editable information about the location.
Instance Attribute Summary collapse
-
#can_delete ⇒ Boolean
(also: #can_delete?)
Output only.
-
#can_have_business_calls ⇒ Boolean
(also: #can_have_business_calls?)
Output only.
-
#can_have_food_menus ⇒ Boolean
(also: #can_have_food_menus?)
Output only.
-
#can_modify_service_list ⇒ Boolean
(also: #can_modify_service_list?)
Output only.
-
#can_operate_health_data ⇒ Boolean
(also: #can_operate_health_data?)
Output only.
-
#can_operate_local_post ⇒ Boolean
(also: #can_operate_local_post?)
Output only.
-
#can_operate_lodging_data ⇒ Boolean
(also: #can_operate_lodging_data?)
Output only.
-
#duplicate_location ⇒ String
Output only.
-
#has_google_updated ⇒ Boolean
(also: #has_google_updated?)
Output only.
-
#has_pending_edits ⇒ Boolean
(also: #has_pending_edits?)
Output only.
-
#has_voice_of_merchant ⇒ Boolean
(also: #has_voice_of_merchant?)
Output only.
-
#is_particularly_personal_place ⇒ Boolean
(also: #is_particularly_personal_place?)
Output only.
-
#maps_uri ⇒ String
Output only.
-
#new_review_uri ⇒ String
Output only.
-
#place_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
1009 1010 1011 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_delete ⇒ Boolean Also known as: can_delete?
Output only. Indicates whether the location can be deleted using the API.
Corresponds to the JSON property canDelete
916 917 918 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 916 def can_delete @can_delete end |
#can_have_business_calls ⇒ Boolean Also known as: can_have_business_calls?
Output only. Indicates if the listing is eligible for business calls.
Corresponds to the JSON property canHaveBusinessCalls
922 923 924 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 922 def can_have_business_calls @can_have_business_calls end |
#can_have_food_menus ⇒ Boolean Also known as:
Output only. Indicates if the listing is eligible for food menu.
Corresponds to the JSON property canHaveFoodMenus
928 929 930 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 928 def @can_have_food_menus end |
#can_modify_service_list ⇒ Boolean Also known as: can_modify_service_list?
Output only. Indicates if the listing can modify the service list.
Corresponds to the JSON property canModifyServiceList
934 935 936 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 934 def can_modify_service_list @can_modify_service_list end |
#can_operate_health_data ⇒ Boolean Also known as: can_operate_health_data?
Output only. Indicates whether the location can operate on Health data.
Corresponds to the JSON property canOperateHealthData
940 941 942 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 940 def can_operate_health_data @can_operate_health_data end |
#can_operate_local_post ⇒ Boolean Also known as: can_operate_local_post?
Output only. Indicates if the listing can manage local posts. Deprecated: This
field is no longer populated and will be removed in a future version.
Corresponds to the JSON property canOperateLocalPost
947 948 949 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 947 def can_operate_local_post @can_operate_local_post end |
#can_operate_lodging_data ⇒ Boolean Also known as: can_operate_lodging_data?
Output only. Indicates whether the location can operate on Lodging data.
Corresponds to the JSON property canOperateLodgingData
953 954 955 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 953 def can_operate_lodging_data @can_operate_lodging_data end |
#duplicate_location ⇒ String
Output only. The location resource that this location duplicates.
Corresponds to the JSON property duplicateLocation
959 960 961 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 959 def duplicate_location @duplicate_location end |
#has_google_updated ⇒ Boolean Also known as: has_google_updated?
Output only. Indicates whether the place ID associated with this location has
updates that need to be updated or rejected by the client. If this boolean is
set, you should call the getGoogleUpdated method to look up information that'
s needs to be verified.
Corresponds to the JSON property hasGoogleUpdated
967 968 969 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 967 def has_google_updated @has_google_updated end |
#has_pending_edits ⇒ Boolean Also known as: has_pending_edits?
Output only. Indicates whether any of this Location's properties are in the
edit pending state.
Corresponds to the JSON property hasPendingEdits
974 975 976 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 974 def has_pending_edits @has_pending_edits end |
#has_voice_of_merchant ⇒ Boolean Also known as: has_voice_of_merchant?
Output only. Indicates if the listing has Voice of Merchant. If this boolean
is false, you should call the locations.getVoiceOfMerchantState API to get
details as to why they do not have Voice of Merchant.
Corresponds to the JSON property hasVoiceOfMerchant
982 983 984 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 982 def has_voice_of_merchant @has_voice_of_merchant end |
#is_particularly_personal_place ⇒ Boolean Also known as: is_particularly_personal_place?
Output only.
Corresponds to the JSON property isParticularlyPersonalPlace
988 989 990 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 988 def is_particularly_personal_place @is_particularly_personal_place end |
#maps_uri ⇒ String
Output only. A link to the location on Maps.
Corresponds to the JSON property mapsUri
994 995 996 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 994 def maps_uri @maps_uri end |
#new_review_uri ⇒ String
Output only. A link to the page on Google Search where a customer can leave a
review for the location.
Corresponds to the JSON property newReviewUri
1000 1001 1002 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1000 def new_review_uri @new_review_uri end |
#place_id ⇒ String
Output only. If this locationappears on Google Maps, this field is populated
with the place ID for the location. This ID can be used in various Places APIs.
This field can be set during Create calls, but not for Update.
Corresponds to the JSON property placeId
1007 1008 1009 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1007 def place_id @place_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1014 def update!(**args) @can_delete = args[:can_delete] if args.key?(:can_delete) @can_have_business_calls = args[:can_have_business_calls] if args.key?(:can_have_business_calls) @can_have_food_menus = args[:can_have_food_menus] if args.key?(:can_have_food_menus) @can_modify_service_list = args[:can_modify_service_list] if args.key?(:can_modify_service_list) @can_operate_health_data = args[:can_operate_health_data] if args.key?(:can_operate_health_data) @can_operate_local_post = args[:can_operate_local_post] if args.key?(:can_operate_local_post) @can_operate_lodging_data = args[:can_operate_lodging_data] if args.key?(:can_operate_lodging_data) @duplicate_location = args[:duplicate_location] if args.key?(:duplicate_location) @has_google_updated = args[:has_google_updated] if args.key?(:has_google_updated) @has_pending_edits = args[:has_pending_edits] if args.key?(:has_pending_edits) @has_voice_of_merchant = args[:has_voice_of_merchant] if args.key?(:has_voice_of_merchant) @is_particularly_personal_place = args[:is_particularly_personal_place] if args.key?(:is_particularly_personal_place) @maps_uri = args[:maps_uri] if args.key?(:maps_uri) @new_review_uri = args[:new_review_uri] if args.key?(:new_review_uri) @place_id = args[:place_id] if args.key?(:place_id) end |