Class: Google::Apis::MybusinessbusinessinformationV1::ServiceItem
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessbusinessinformationV1::ServiceItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessbusinessinformation_v1/classes.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb,
lib/google/apis/mybusinessbusinessinformation_v1/representations.rb
Overview
A message that describes a single service item. It is used to describe the type of service that the merchant provides. For example, haircut can be a service.
Instance Attribute Summary collapse
-
#free_form_service_item ⇒ Google::Apis::MybusinessbusinessinformationV1::FreeFormServiceItem
Represents a free-form service offered by the merchant.
-
#price ⇒ Google::Apis::MybusinessbusinessinformationV1::Money
Represents an amount of money with its currency type.
-
#structured_service_item ⇒ Google::Apis::MybusinessbusinessinformationV1::StructuredServiceItem
Represents a structured service offered by the merchant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceItem
constructor
A new instance of ServiceItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceItem
Returns a new instance of ServiceItem.
1635 1636 1637 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#free_form_service_item ⇒ Google::Apis::MybusinessbusinessinformationV1::FreeFormServiceItem
Represents a free-form service offered by the merchant. These are services
that are not exposed as part of our structure service data. The merchant
manually enters the names for such services using a geomerchant surface.
Corresponds to the JSON property freeFormServiceItem
1622 1623 1624 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1622 def free_form_service_item @free_form_service_item end |
#price ⇒ Google::Apis::MybusinessbusinessinformationV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property price
1627 1628 1629 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1627 def price @price end |
#structured_service_item ⇒ Google::Apis::MybusinessbusinessinformationV1::StructuredServiceItem
Represents a structured service offered by the merchant. For eg:
toilet_installation.
Corresponds to the JSON property structuredServiceItem
1633 1634 1635 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1633 def structured_service_item @structured_service_item end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1640 1641 1642 1643 1644 |
# File 'lib/google/apis/mybusinessbusinessinformation_v1/classes.rb', line 1640 def update!(**args) @free_form_service_item = args[:free_form_service_item] if args.key?(:free_form_service_item) @price = args[:price] if args.key?(:price) @structured_service_item = args[:structured_service_item] if args.key?(:structured_service_item) end |